/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { Editor as Lo } from "./Editor.mjs";
import { EditorToolsSettings as jo } from "./config/toolsSettings.mjs";
import { EditorUtils as Qo } from "./utils/main.mjs";
import { Selection as e, SelectionRange as o, TextSelection as t, NodeSelection as r, AllSelection as l, EditorState as n, Plugin as a, PluginKey as i, Transaction as p, Decoration as d, DecorationSet as s, EditorView as m, Node as c, ResolvedPos as u, NodeRange as f, Fragment as g, Slice as x, ReplaceError as C, Mark as S, Schema as R, NodeType as T, MarkType as y, ContentMatch as k, DOMParser as w, DOMSerializer as I, Transform as P, Step as b, StepResult as M, joinPoint as N, canJoin as A, canSplit as B, insertPoint as D, dropPoint as K, liftTarget as h, findWrapping as E, StepMap as F, MapResult as L, Mapping as H, AddMarkStep as j, RemoveMarkStep as z, ReplaceStep as Q, ReplaceAroundStep as v, replaceStep as O, deleteSelection as U, joinBackward as J, selectNodeBackward as V, joinForward as W, selectNodeForward as q, joinUp as G, joinDown as X, lift as Y, newlineInCode as Z, exitCode as _, createParagraphNear as $, liftEmptyBlock as ee, splitBlock as oe, splitBlockKeepMarks as te, selectParentNode as re, selectAll as le, wrapIn as ne, setBlockType as ae, toggleMark as ie, autoJoin as pe, chainCommands as de, pcBaseKeymap as se, macBaseKeymap as me, baseKeymap as ce, history as ue, undo as fe, redo as ge, undoDepth as xe, redoDepth as Ce, InputRule as Se, inputRules as Re, undoInputRule as Te, emDash as ye, ellipsis as ke, openDoubleQuote as we, closeDoubleQuote as Ie, openSingleQuote as Pe, closeSingleQuote as be, smartQuotes as Me, wrappingInputRule as Ne, textblockTypeInputRule as Ae, keymap as Be, keydownHandler as De, orderedList as Ke, bulletList as he, listItem as Ee, addListNodes as Fe, wrapInList as Le, splitListItem as He, liftListItem as je, sinkListItem as ze, dropCursor as Qe, gapCursor as ve, tableEditing as Oe, fixTables as Ue, fixTablesKey as Je, cellAround as Ve, isInTable as We, selectionCell as qe, moveCellForward as Ge, inSameTable as Xe, findCell as Ye, colCount as Ze, nextCell as _e, removeColSpan as $e, addColSpan as eo, columnIsHeader as oo, tableNodes as to, tableNodeTypes as ro, CellSelection as lo, TableMap as no, tableEditingKey as ao, columnResizing as io, updateColumnsOnResize as po, selectedRect as so, addColumn as mo, addColumnBefore as co, addColumnAfter as uo, deleteColumn as fo, rowIsHeader as go, addRow as xo, addRowBefore as Co, addRowAfter as So, deleteRow as Ro, mergeCells as To, splitCell as yo, splitCellWithType as ko, setCellAttr as wo, toggleHeader as Io, toggleHeaderRow as Po, toggleHeaderColumn as bo, toggleHeaderCell as Mo, goToNextCell as No, deleteTable as Ao, columnResizingPluginKey as Bo } from "@progress/kendo-editor-common";
import { Align as Oo } from "./tools/align.mjs";
import { Indent as Jo } from "./tools/indent.mjs";
import { List as Wo } from "./tools/lists.mjs";
import { Outdent as Go } from "./tools/outdent.mjs";
import { InlineFormat as Yo } from "./tools/inlineFormat.mjs";
import { FontName as _o } from "./tools/fontStyle.mjs";
import { FormatBlock as et } from "./tools/formatBlock.mjs";
import { ProseMirror as tt } from "./tools/proseMirrorTool.mjs";
import { LinkTool as lt } from "./tools/insertLink.mjs";
import { Unlink as at } from "./tools/unlink.mjs";
import { CleanFormatting as pt } from "./tools/cleanFormatting.mjs";
import { SelectAll as st } from "./tools/selectAll.mjs";
import { InsertImage as ct } from "./tools/insertImage.mjs";
import { InsertTable as ft } from "./tools/insertTable/tool.mjs";
import { ViewHtml as xt } from "./tools/viewHtml.mjs";
import { Pdf as St } from "./tools/pdf.mjs";
import { Print as Tt } from "./tools/print.mjs";
import { FindAndReplace as kt } from "./tools/findReplace.mjs";
import { ApplyColor as It } from "./tools/applyColor.mjs";
const Do = Bo, ho = {
  // prosemirror-state
  Selection: e,
  SelectionRange: o,
  TextSelection: t,
  NodeSelection: r,
  AllSelection: l,
  EditorState: n,
  Plugin: a,
  PluginKey: i,
  Transaction: p,
  // prosemirror-view
  Decoration: d,
  DecorationSet: s,
  EditorView: m,
  // prosemirror-model
  Node: c,
  ResolvedPos: u,
  NodeRange: f,
  Fragment: g,
  Slice: x,
  ReplaceError: C,
  Mark: S,
  Schema: R,
  NodeType: T,
  MarkType: y,
  ContentMatch: k,
  DOMParser: w,
  DOMSerializer: I,
  // prosemirror-transform
  Transform: P,
  Step: b,
  StepResult: M,
  joinPoint: N,
  canJoin: A,
  canSplit: B,
  insertPoint: D,
  dropPoint: K,
  liftTarget: h,
  findWrapping: E,
  StepMap: F,
  MapResult: L,
  Mapping: H,
  AddMarkStep: j,
  RemoveMarkStep: z,
  ReplaceStep: Q,
  ReplaceAroundStep: v,
  replaceStep: O,
  // prosemirror-commands
  deleteSelection: U,
  joinBackward: J,
  selectNodeBackward: V,
  joinForward: W,
  selectNodeForward: q,
  joinUp: G,
  joinDown: X,
  lift: Y,
  newlineInCode: Z,
  exitCode: _,
  createParagraphNear: $,
  liftEmptyBlock: ee,
  splitBlock: oe,
  splitBlockKeepMarks: te,
  selectParentNode: re,
  selectAll: le,
  wrapIn: ne,
  setBlockType: ae,
  toggleMark: ie,
  autoJoin: pe,
  chainCommands: de,
  pcBaseKeymap: se,
  macBaseKeymap: me,
  baseKeymap: ce,
  // prosemirror-history
  history: ue,
  undo: fe,
  redo: ge,
  undoDepth: xe,
  redoDepth: Ce,
  // prosemirror-inputrules
  InputRule: Se,
  inputRules: Re,
  undoInputRule: Te,
  emDash: ye,
  ellipsis: ke,
  openDoubleQuote: we,
  closeDoubleQuote: Ie,
  openSingleQuote: Pe,
  closeSingleQuote: be,
  smartQuotes: Me,
  wrappingInputRule: Ne,
  textblockTypeInputRule: Ae,
  // prosemirror-keymap
  keymap: Be,
  keydownHandler: De,
  // prosemirror-schema-list
  orderedList: Ke,
  bulletList: he,
  listItem: Ee,
  addListNodes: Fe,
  wrapInList: Le,
  splitListItem: He,
  liftListItem: je,
  sinkListItem: ze,
  // prosemirror-dropcursor
  dropCursor: Qe,
  // prosemirror-gapcursor
  gapCursor: ve,
  // prosemirror-tables
  tableEditing: Oe,
  fixTables: Ue,
  fixTablesKey: Je,
  cellAround: Ve,
  isInTable: We,
  selectionCell: qe,
  moveCellForward: Ge,
  inSameTable: Xe,
  findCell: Ye,
  colCount: Ze,
  nextCell: _e,
  removeColSpan: $e,
  addColSpan: eo,
  columnIsHeader: oo,
  tableNodes: to,
  tableNodeTypes: ro,
  CellSelection: lo,
  TableMap: no,
  tableEditingKey: ao,
  columnResizing: io,
  columnResizingPluginKey: Do,
  updateColumnsOnResize: po,
  selectedRect: so,
  addColumn: mo,
  addColumnBefore: co,
  addColumnAfter: uo,
  deleteColumn: fo,
  rowIsHeader: go,
  addRow: xo,
  addRowBefore: Co,
  addRowAfter: So,
  deleteRow: Ro,
  mergeCells: To,
  splitCell: yo,
  splitCellWithType: ko,
  setCellAttr: wo,
  toggleHeader: Io,
  toggleHeaderRow: Po,
  toggleHeaderColumn: bo,
  toggleHeaderCell: Mo,
  goToNextCell: No,
  deleteTable: Ao
};
export {
  Oo as Align,
  It as ApplyColor,
  pt as CleanFormatting,
  Lo as Editor,
  jo as EditorToolsSettings,
  Qo as EditorUtils,
  kt as FindAndReplace,
  _o as FontName,
  et as FormatBlock,
  Jo as Indent,
  Yo as InlineFormat,
  ct as InsertImage,
  ft as InsertTable,
  lt as LinkTool,
  Wo as List,
  Go as Outdent,
  St as Pdf,
  Tt as Print,
  ho as ProseMirror,
  tt as ProseMirrorTool,
  st as SelectAll,
  at as Unlink,
  xt as ViewHtml
};
